==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Dimension/ts/Dimension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Dimension</name>
    <message>
        <location filename="../Dimension.js" line="+63"/>
        <source>No prefix</source>
        <translation>无前缀</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric screw</source>
        <translation>公制螺丝</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diameter</source>
        <translation>直径</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>正/负</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>约等于</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>渐进等于</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>正方形</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Dimension Tools</source>
        <translation>尺寸工具</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show dimension tools</source>
        <translation>显示尺寸工具</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>D&amp;imension</source>
        <translation>尺寸(&amp;i)</translation>
    </message>
    <message>
        <location filename="../Dimension.ui" line="+29"/>
        <source>Label:</source>
        <translation>标签：</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Enter fixed label or leave empty for automatic label</source>
        <translation>输入固定标签或留空以使用自动标签</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Upper tolerance</source>
        <translation>上公差</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Lower tolerance</source>
        <translation>下公差</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation>绘图的显示比例</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Dimension/ts/Dimension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Dimension</name>
    <message>
        <location filename="../Dimension.js" line="+63"/>
        <source>No prefix</source>
        <translation>无前缀</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric screw</source>
        <translation>公制螺丝</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diameter</source>
        <translation>直径</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>正/负</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>约等于</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>渐进等于</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>正方形</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Δ</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Dimension Tools</source>
        <translation>标注工具</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show dimension tools</source>
        <translation>显示标注工具</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>D&amp;imension</source>
        <translation>标注(&amp;i)</translation>
    </message>
    <message>
        <location filename="../Dimension.ui" line="+29"/>
        <source>Label:</source>
        <translation>标签：</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Enter fixed label or leave empty for automatic label</source>
        <translation>输入固定标签或留空以使用自动标签</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Upper tolerance</source>
        <translation>上公差</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Lower tolerance</source>
        <translation>下公差</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Scale</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation>绘图的显示比例</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
</context>
</TS>
